@@ -1,5 +1,5 @@
 /*--------------------------------------------------------------------
- *    $Id: grdblend.c,v 1.40 2006/05/12 07:23:02 pwessel Exp $
+ *    $Id: grdblend.c,v 1.43 2006/10/24 21:03:28 remko Exp $
  *
  *	Copyright (c) 1991-2006 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
@@ -70,6 +70,7 @@ struct GRDBLEND_INFO {	/* Structure with info about each input grid file */
 	int in_i0, in_i1, out_i0, out_i1;		/* Indices of outer and inner x-coordinates (in output grid coordinates) */
 	int in_j0, in_j1, out_j0, out_j1;		/* Indices of outer and inner y-coordinates (in output grid coordinates) */
 	BOOLEAN outside;				/* TRUE if the current output row is outside the range of this grid */
+	BOOLEAN invert;					/* TRUE if weight was given as negative and we want to taper to zero INSIDE the grid region */
 	double weight, wt_y, wxr, wxl, wyu, wyd;	/* Various weighting factors used for cosine-taper weights */
 	double w_in, e_in, s_in, n_in;			/* Boundaries of inner region */
 	float *z;					/* Row vector holding the current row from this file */
@@ -171,6 +172,7 @@ int main (int argc, char **argv)
 		fprintf (stderr, "\t<blendfile> is an ASCII file (or stdin) with blending parameters for each input grid\n");
 		fprintf (stderr, "\t   Each record has:  grdfilename -Rw/e/s/n weight\n");
 		fprintf (stderr, "\t   Relative weights are <weight> inside the given -R and cosine taper to 0 at actual -R.\n");
+		fprintf (stderr, "\t   Give a negative weight to invert the sense of the taper (i.e., |<weight>| outside given R.\n");
 		fprintf (stderr, "\t-G <grdfile> is the name of the final 2-D binary data set\n");
 		GMT_inc_syntax ('I', 0);
 		GMT_explain_option ('R');
@@ -198,7 +200,8 @@ int main (int argc, char **argv)
 		fprintf (stderr, "%s: GMT SYNTAX ERROR -G:  Must specify output file\n", GMT_program);
 		error++;
 	}
-	type = GMT_grdformats[GMT_grd_get_format (Ctrl->G.file, &S.header)][0];
+	GMT_grd_get_format (Ctrl->G.file, &S.header, FALSE);
+	type = GMT_grdformats[S.header.type][0];
 	if (Ctrl->Q.active && (type == 'c' || type == 'n')) {
 		fprintf (stderr, "%s: GMT SYNTAX ERROR -Q:  Output grdfile cannot be netCDF format\n", GMT_program);
 		error++;
@@ -277,6 +280,7 @@ int main (int argc, char **argv)
 				else								/* Inside inner region, weight = 1 */
 					wt_x = 1.0;
 				wt = wt_x * blend[k].wt_y;					/* Actual weight is 2-D cosine taper */
+				if (blend[k].invert) wt = blend[k].weight - wt;			/* Invert the sense of the tapering */
 				z[col] += (float)(wt * blend[k].z[kk]);				/* Add up weighted z*w sum */
 				w += wt;							/* Add up the weight sum */
 				m++;								/* Add up the number of contributing grids */
@@ -339,7 +343,7 @@ int init_blend_job (FILE *fp, struct GRD_HEADER *h, struct GRDBLEND_INFO **blend
 	int n = 0, nr, one_or_zero = 0;
 	size_t n_alloc = GMT_SMALL_CHUNK;
 	struct GRDBLEND_INFO *B;
-	char line[BUFSIZ], r_in[GMT_LONG_TEXT], file[GMT_LONG_TEXT], type;
+	char line[BUFSIZ], r_in[GMT_LONG_TEXT], file[GMT_LONG_TEXT], type, *sense[2] = {"normal", "inverse"};
 	void decode_R (char *string, double *w, double *e, double *s, double *n);
 
 	B = (struct GRDBLEND_INFO *) GMT_memory (VNULL, n_alloc, sizeof (struct GRDBLEND_INFO), GMT_program);
@@ -358,6 +362,12 @@ int init_blend_job (FILE *fp, struct GRD_HEADER *h, struct GRDBLEND_INFO **blend
 			exit (EXIT_FAILURE);
 		}
 
+		/* Skip the file if its outer region does not lie within the final grid region */
+		if (h->x_min > B[n].e_in || h->x_max < B[n].w_in || h->y_min > B[n].n_in || h->y_max < B[n].s_in) {
+			fprintf (stderr, "%s: Warning: File %s entirely outside final grid region (skipped)\n", GMT_program, file);
+			continue;
+		}
+
 		/* Various sanity checking - e.g., all grid of same registration type and grid spacing */
 
 		if (n == 0) {
@@ -376,6 +386,11 @@ int init_blend_job (FILE *fp, struct GRD_HEADER *h, struct GRDBLEND_INFO **blend
 			fprintf (stderr, "%s: File %s has different y-increment (%g) that the chosen output increment (%g)\n", GMT_program, file, B[n].G.header.y_inc, h->y_inc);
 			exit (EXIT_FAILURE);
 		}
+		if (B[n].weight < 0.0) {	/* Negative weight means invert sense of taper */
+			B[n].weight = fabs (B[n].weight);
+			B[n].invert = TRUE;
+		}
+
 		GMT_open_grd (file, &B[n].G, 'r');	/* Open the grid for incremental row reading */
 
 		/* Here, i0, j0 is the very first col, row to read, while i1, j1 is the very last col, row to read .
@@ -411,8 +426,8 @@ int init_blend_job (FILE *fp, struct GRD_HEADER *h, struct GRDBLEND_INFO **blend
 		/* Allocate space for one entire row */
 
 		B[n].z = (float *) GMT_memory (VNULL, (size_t)(B[n].G.header.nx), sizeof (float), GMT_program);
-		if (gmtdefs.verbose) fprintf (stderr, "%s: Blend file %s in %g/%g/%g/%g with weight %g [%d-%d]\n",
-			GMT_program, B[n].G.header.name, B[n].w_in, B[n].e_in, B[n].s_in, B[n].n_in, B[n].weight, B[n].out_j0, B[n].out_j1);
+		if (gmtdefs.verbose) fprintf (stderr, "%s: Blend file %s in %g/%g/%g/%g with %s weight %g [%d-%d]\n",
+			GMT_program, B[n].G.header.name, B[n].w_in, B[n].e_in, B[n].s_in, B[n].n_in, sense[B[n].invert], B[n].weight, B[n].out_j0, B[n].out_j1);
 
 		n++;
 		if (n == (int)n_alloc) {
