@@ -1,5 +1,5 @@
 /*--------------------------------------------------------------------
- *	$Id: grdinfo.c,v 1.37 2006/05/14 01:43:04 pwessel Exp $
+ *	$Id: grdinfo.c,v 1.39 2006/09/30 02:34:00 pwessel Exp $
  *
  *	Copyright (c) 1991-2006 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
@@ -301,7 +301,10 @@ int main (int argc, char **argv)
 				fprintf (GMT_stdout, "\t");	GMT_ascii_output_one (GMT_stdout, stdev, 2);
 				fprintf (GMT_stdout, "\t");	GMT_ascii_output_one (GMT_stdout, rms, 2);
 			}
-			if (Ctrl->M.active) fprintf (GMT_stdout, "\t%u", n_nan);
+			if (Ctrl->M.active) {
+				fprintf (GMT_stdout, "\t");
+				PRINT_SIZE_T (GMT_stdout, n_nan);
+			}
 			fprintf (GMT_stdout, "\n");
 		}
 		else if (!(Ctrl->T.active || Ctrl->I.active)) {
@@ -375,7 +378,7 @@ int main (int argc, char **argv)
 			else if (Ctrl->F.active) {
 				fprintf (GMT_stdout, "%s: zmin: %g\n", file, grd.z_min);
 				fprintf (GMT_stdout, "%s: zmax: %g\n", file, grd.z_max);
-				fprintf (GMT_stdout, "%s: name: %s\n", file, grd.z_units);
+			 	fprintf (GMT_stdout, "%s: name: %s\n", file, grd.z_units);
 			}
 			else {
 				fprintf (GMT_stdout, "%s: z_min: ", file);
@@ -389,7 +392,11 @@ int main (int argc, char **argv)
 			if (isalpha ((int)text[strlen(text)-1])) text[strlen(text)-1] = '\0';	/* Chop of trailing WESN flag here */
 			sprintf (format, "%s: scale_factor: %s add_offset: %%s\n", file, gmtdefs.d_format);
 			fprintf (GMT_stdout, format, grd.z_scale_factor, text);
-			if (n_nan) fprintf (GMT_stdout, "%s: %u nodes set to NaN\n", file, n_nan);
+			if (n_nan) {
+				fprintf (GMT_stdout, "%s: ", file);
+				PRINT_SIZE_T (GMT_stdout, n_nan);
+				fprintf (GMT_stdout, " nodes set to NaN\n");
+			}
 			if (Ctrl->L.norm == 1) {
 				fprintf (GMT_stdout, "%s: median: ", file);	GMT_ascii_output_one (GMT_stdout, median, 2);
 				fprintf (GMT_stdout, " scale: ");		GMT_ascii_output_one (GMT_stdout, scale, 2);
