@@ -1,5 +1,5 @@
 /*--------------------------------------------------------------------
- *	$Id: pslegend.c,v 1.70 2006/04/13 08:34:41 pwessel Exp $
+ *	$Id: pslegend.c,v 1.75 2006/10/28 03:12:50 pwessel Exp $
  *
  *	Copyright (c) 1991-2006 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
@@ -76,7 +76,7 @@ int main (int argc, char **argv)
 	char size[GMT_LONG_TEXT], angle[GMT_LONG_TEXT], mapscale[GMT_LONG_TEXT], font[GMT_LONG_TEXT], lspace[GMT_LONG_TEXT];
 	char tw[GMT_LONG_TEXT], jj[GMT_LONG_TEXT], line[BUFSIZ], vpen[GMT_LONG_TEXT], script[GMT_LONG_TEXT];
 	char sarg[GMT_LONG_TEXT], sparg[BUFSIZ], *jarg = CNULL, txtcolor[GMT_LONG_TEXT], psxy[GMT_LONG_TEXT], pstext[GMT_LONG_TEXT];
-	char bar_cpt[GMT_LONG_TEXT], bar_gap[GMT_LONG_TEXT], bar_height[GMT_LONG_TEXT], bar_opts[BUFSIZ];
+	char bar_cpt[GMT_LONG_TEXT], bar_gap[GMT_LONG_TEXT], bar_height[GMT_LONG_TEXT], bar_opts[BUFSIZ], mode;
 	
 	int i, k, n, justify = 0, n_columns = 1, error = 0, symbol_number = 0, n_files = 0, colon, n_scan;
 	
@@ -174,7 +174,7 @@ int main (int argc, char **argv)
 				case 'G':	/* Inside legend fill? */
 					Ctrl->G.active = TRUE;
 					if (GMT_getfill (&argv[i][2], &Ctrl->G.fill)) {	/* We check syntax here */
-						GMT_fill_syntax ('G');
+						GMT_fill_syntax ('G', " ");
 						error++;
 					}
 					f = argv[i];		/* Pointer to fill argument */
@@ -228,7 +228,7 @@ int main (int argc, char **argv)
 		GMT_explain_option ('b');
 		fprintf (stderr, "\t-C sets the clearance between legend frame and internal items [0.05i/0.05i]\n");
 		fprintf (stderr, "\t-F Draw border around the legend (using FRAME_PEN) [Default is no border]\n");
-		fprintf (stderr, "\t-G set the fill for the legend box [no fill]\n");
+		GMT_fill_syntax ('G', "Set the fill for the legend box [Default is no fill].");
 		GMT_explain_option ('K');
 		GMT_explain_option ('O');
 		GMT_explain_option ('P');
@@ -299,14 +299,25 @@ int main (int argc, char **argv)
 	Ctrl->D.lon -= 0.5 * ((justify-1)%4) * Ctrl->D.width;
 	Ctrl->D.lat -= 0.5 * (justify/4) * Ctrl->D.height;
 
+	/* Initialize psxy and pstext call strings with appropriate values */
+	
+	if (GMT_ps.absolute) {	/* Must pass the -Xa -Ya settings to every psxy and pstext call */
+		mode = 'a';
+		sprintf (pstext, "pstext -R -JX -O -K -X%c%gi -Y%c%gi %s", mode, Ctrl->D.lon, mode, Ctrl->D.lat, sparg);
+		sprintf (psxy, "psxy -R -JX -O -K -X%c%gi -Y%c%gi %s", mode, Ctrl->D.lon, mode, Ctrl->D.lat, sparg);
+	}
+	else {			/* No need to pass, -X0 -Y0 are set implicitly */
+		mode = 'r';
+		sprintf (pstext, "pstext -R -JX -O -K %s", sparg);
+		sprintf (psxy, "psxy -R -JX -O -K %s", sparg);
+	}
+	
 	/* First draw legend frame box.  Note -JX%gi/-%gi which means y is positive down from the top of the box */
 
 	if (Ctrl->F.active || Ctrl->G.active)
-		sprintf (cmd, "psbasemap -R0/%g/0/%g -JX%gi/-%gi -X%gi -Y%gi -K %s", Ctrl->D.width, Ctrl->D.height, Ctrl->D.width, Ctrl->D.height, Ctrl->D.lon, Ctrl->D.lat, sparg);
+		sprintf (cmd, "psbasemap -R0/%g/0/%g -JX%gi/-%gi -X%c%gi -Y%c%gi -K %s", Ctrl->D.width, Ctrl->D.height, Ctrl->D.width, Ctrl->D.height, mode, Ctrl->D.lon, mode, Ctrl->D.lat, sparg);
 	else
-		sprintf (cmd, "psxy -R0/%g/0/%g -JX%gi/-%gi %s -X%gi -Y%gi -K %s", Ctrl->D.width, Ctrl->D.height, Ctrl->D.width, Ctrl->D.height, null, Ctrl->D.lon, Ctrl->D.lat, sparg);
-	sprintf (pstext, "pstext -R -JX -O -K %s", sparg);
-	sprintf (psxy, "psxy -R -JX -O -K %s", sparg);
+		sprintf (cmd, "psxy -R0/%g/0/%g -JX%gi/-%gi %s -X%c%gi -Y%c%gi -K %s", Ctrl->D.width, Ctrl->D.height, Ctrl->D.width, Ctrl->D.height, null, mode, Ctrl->D.lon, mode, Ctrl->D.lat, sparg);
 	if (GMT_ps.portrait) strcat (cmd, " -P");
 	if (Ctrl->F.active) strcat (cmd, " -B0");
 	if (GMT_ps.overlay) strcat (cmd, " -O");
@@ -390,7 +401,7 @@ int main (int argc, char **argv)
 				flush_paragraph = FALSE;
 				if (n_columns > 1 && symbol_number > 0 && symbol_number%n_columns != 0) y0 += half_line_spacing, symbol_number = 0;	/* Did not end with full column */
 				n_scan = sscanf (&line[2], "%s %s %s %s %s %s", txt_a, txt_b, txt_c, txt_d, txt_e, txt_f);
-				if (txt_d[0] != 'f') txt_d[0] = 'p';	/* Default is plain unless f is given */
+				k = (txt_d[0] != 'f') ? 1 : 0;	/* Determines if we start -L with f or not */
 				for (i = colon = 0; txt_c[i] && colon != 2; i++) if (txt_c[i] == ':') colon++;
 				if (colon) {	/* Specified alternate label (could be upper case, hence 0.85) and justification */
 					d_off = 0.0;
@@ -405,14 +416,16 @@ int main (int argc, char **argv)
 				x_off = 0.5 * Ctrl->D.width;
 				y_use = Ctrl->D.height - y0;
 				if (!strcmp (txt_a, "-"))	/* No longitude needed */
-					sprintf (mapscale, "%cx%gi/%gi/%s/%s", txt_d[0], 0.5 * Ctrl->D.width, y_use, txt_b, txt_c);
+					sprintf (mapscale, "fx%gi/%gi/%s/%s", 0.5 * Ctrl->D.width, y_use, txt_b, txt_c);
 				else				/* Gave both lon and lat for scale */
-					sprintf (mapscale, "%cx%gi/%gi/%s/%s/%s", txt_d[0], 0.5 * Ctrl->D.width, y_use, txt_a, txt_b, txt_c);
+					sprintf (mapscale, "fx%gi/%gi/%s/%s/%s", 0.5 * Ctrl->D.width, y_use, txt_a, txt_b, txt_c);
 
 				if (n_scan == 6)	/* Gave specific -R -J on M line */
-					fprintf (fpo, "psbasemap %s %s -O -K -L%s\n", txt_e, txt_f, mapscale);
+					fprintf (fpo, "psbasemap %s %s -O -K -L%s\n", txt_e, txt_f, &mapscale[k]);
 				else	/* Use -R -J supplied to pslegend */
-					fprintf (fpo, "psbasemap -R%g/%g/%g/%g %s -O -K -L%s\n", west, east, south, north, jarg, mapscale);
+					fprintf (fpo, "psbasemap -R%g/%g/%g/%g %s -O -K -L%s\n", west, east, south, north, jarg, &mapscale[k]);
+				/* Reset -R -J by calling a dummy psxy /dev/null */
+				fprintf (fpo, "psxy -R0/%g/0/%g -JX%gi/-%gi -O -K %s\n", Ctrl->D.width, Ctrl->D.height, Ctrl->D.width, Ctrl->D.height, null);
 				d_off = 0.0;
 				if (colon && txt_c[i] == 'b') {	/* Specified bottom justification */
 					d_off = 0.75 * gmtdefs.label_font_size / 72.0 + fabs(gmtdefs.label_offset);
@@ -587,7 +600,7 @@ int main (int argc, char **argv)
 
 	if (flush_paragraph) fprintf (fpo, "%s -M pslegend_tmp.txt\n%s pslegend_tmp.txt\n", pstext, del);
 	/* Revert to original region (-R), projection and size (-J) and position (-X, -Y) */
-	sprintf (cmd, "psxy %s -R%g/%g/%g/%g %s -X%gi -Y%gi -O %s", null, west, east, south, north, jarg, -Ctrl->D.lon, -Ctrl->D.lat, sparg);
+	sprintf (cmd, "psxy %s -R%g/%g/%g/%g %s -X%c%gi -Y%c%gi -O %s", null, west, east, south, north, jarg, mode, -Ctrl->D.lon+GMT_ps.x_origin, mode, -Ctrl->D.lat+GMT_ps.y_origin, sparg);
 	if (!GMT_ps.last_page) strcat (cmd, " -K");
 	fprintf (fpo, "%s\n", cmd);
 
@@ -626,6 +639,9 @@ void GMT_replace_symbol (char *symbol)
 		case 'd':	/* Diamond */
 			sprintf (new, "kdiamond");
 			break;
+		case 'g':	/* Octagon */
+			sprintf (new, "koctagon");
+			break;
 		case 'h':	/* Hexagon */
 			sprintf (new, "khexagon");
 			break;
