@@ -1,5 +1,5 @@
 /*--------------------------------------------------------------------
- *	$Id: psxyz.c,v 1.92 2006/05/08 07:49:08 pwessel Exp $
+ *	$Id: psxyz.c,v 1.96 2006/10/28 23:51:45 pwessel Exp $
  *
  *	Copyright (c) 1991-2006 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
@@ -184,7 +184,7 @@ int main (int argc, char **argv)
 				case 'G':		/* Set color for symbol or polygon */
 					Ctrl->G.active = TRUE;
 					if (!argv[i][2] || (argv[i][2] && GMT_getfill (&argv[i][2], &Ctrl->G.fill))) {
-						GMT_fill_syntax ('G');
+						GMT_fill_syntax ('G', " ");
 						error++;
 					}
 					break;
@@ -207,7 +207,7 @@ int main (int argc, char **argv)
 				case 'W':		/* Set line attributes */
 					Ctrl->W.active = TRUE;
 					if (argv[i][2] && GMT_getpen (&argv[i][2], &Ctrl->W.pen)) {
-						GMT_pen_syntax ('W');
+						GMT_pen_syntax ('W', " ");
 						error++;
 					}
 					break;
@@ -227,7 +227,6 @@ int main (int argc, char **argv)
 		else
 			n_files++;
 	}
-	if (S.symbol > 0 && Ctrl->C.active) get_rgb = TRUE;
 
 	if (argc == 1 || GMT_give_synopsis_and_exit) {	/* Display usage */
 		fprintf (stderr,"psxyz %s - Plot lines, polygons, and symbols in 3-D\n\n", GMT_VERSION);
@@ -246,11 +245,8 @@ int main (int argc, char **argv)
 		fprintf (stderr, "\t-C Use cpt-file to assign symbol colors based on t-value in 4th column (requires -S)\n");
 		fprintf (stderr, "\t   Without -S, psxyz expects -M lines/polygons and looks for -Z<tval> strings in each multiheader\n");
 		fprintf (stderr, "\t-E set user viewpoint azimuth and elevation [180/90].\n");
-		fprintf (stderr, "\t-G Specify color (for symbols/polygons) or pattern (for polygons). fill can be either\n");
-		fprintf (stderr, "\t   1) <r/g/b> (each 0-255) for color or <gray> (0-255) for gray-shade [0].\n");
-		fprintf (stderr, "\t   2) p[or P]<dpi>/<pattern> for predefined patterns (1-90).\n");
+		GMT_fill_syntax ('G', "Specify color (for symbols/polygons) or pattern (for polygons) [Default is no fill]");
 		fprintf (stderr, "\t   If -G is specified but not -S, psxyz draws a filled polygon.\n");
-		fprintf (stderr, "\t   Default is no fill (transparent symbols or polygons)\n");
 		GMT_explain_option ('H');
 		GMT_explain_option ('Z');
 		GMT_explain_option ('K');
@@ -262,8 +258,8 @@ int main (int argc, char **argv)
 		fprintf (stderr, "\t-Q Do NOT sort symbols based on distance to viewer before plotting\n");
 		fprintf (stderr, "\t-S to select symbol type and symbol size (in %s).  Choose between\n", GMT_unit_names[gmtdefs.measure_unit]);
 		fprintf (stderr, "\t   -(xdash), st(a)r, (b)ar, (c)ircle, (d)iamond, (e)llipse, (f)ront, octa(g)on, (h)exagon\n");
-		fprintf (stderr, "\t   (i)nvtriangle, (k)ustom, (%c)etter, pe(n)tagon, c(o)lumn, (p)oint, (q)uoted line, (r)ect, (s)quare\n", 'l');
-		fprintf (stderr, "\t   (t)riangle, c(u)be, (v)ector, (w)edge, (x)cross, (y)dash, (z)dash\n");
+		fprintf (stderr, "\t   (i)nvtriangle, (j)rotated rectangle, (k)ustom, (%c)etter, pe(n)tagon, c(o)lumn, (p)oint, (q)uoted line,\n", 'l');
+		fprintf (stderr, "\t   (r)ect, (s)quare, (t)riangle, c(u)be, (v)ector, (w)edge, (x)cross, (y)dash, (z)dash\n");
 		fprintf (stderr, "\t   If no size is specified, psxyz expects the 4th column to have sizes.\n");
 		fprintf (stderr, "\t   If no symbol is specified, psxyz expects the last column to have symbol code.\n");
 		fprintf (stderr, "\t   [Note: if -C is selected then 4th means 5th column, etc.]\n");
@@ -275,6 +271,10 @@ int main (int argc, char **argv)
 		fprintf (stderr, "\t     If -SE rather than -Se is selected, psxyz will expect azimuth, and axes in km\n");
 		fprintf (stderr, "\t     and convert azimuths based on the chosen map projection.  If projection is linear then\n");
 		fprintf (stderr, "\t     we scale the minor/major axes by the map scale.\n");
+		fprintf (stderr, "\t   Rotatable Rectangle: Direction, x-dimension, and y-dimension are expected in columns 4, 5, and 6.\n");
+		fprintf (stderr, "\t     If -SJ rather than -Sj is selected, psxyz will expect azimuth, and dimensions in km\n");
+		fprintf (stderr, "\t     and convert azimuths based on the chosen map projection.  If projection is linear then\n");
+		fprintf (stderr, "\t     we scale the rectangle dimension by the map scale.\n");
 		fprintf (stderr, "\t   Fronts: Give tickgap/ticklen[dir][type][:offset], where\n");
 		fprintf (stderr, "\t     dir    = Plot symbol to the l(eft) or r(ight) of front [Default is centered]\n");
 		fprintf (stderr, "\t     type   =  b(ox), c(ircle), f(ault), s(lip), t(riangle) [Default is f]\n");
@@ -305,7 +305,7 @@ int main (int argc, char **argv)
 		fprintf (stderr, "\t   Wedges: the start and stop directions of pie wedge must be in input columns 4 and 5.\n");
 		fprintf (stderr, "\t     If -SW rather than -Sw is selected, psxy will expect two azimuths instead.\n");
 		GMT_explain_option ('V');
-		fprintf (stderr, "\t-W sets pen attributes [width = %gp, color = black, solid line].\n", Ctrl->W.pen.width);
+		GMT_pen_syntax ('W', "sets pen attributes");
 		fprintf (stderr, "\t   Implicitly draws symbol outline with this pen.\n");
 		GMT_explain_option ('X');
 		GMT_explain_option ('c');
@@ -320,7 +320,7 @@ int main (int argc, char **argv)
 
 	/* Check that the options selected are mutually consistent */
 
-	if (Ctrl->S.active && GMT_decode_symbol_option (Ctrl->S.arg, &S, 1, TRUE)) {
+	if (Ctrl->S.active && GMT_parse_symbol_option (Ctrl->S.arg, &S, 1, TRUE)) {
 		fprintf (stderr, "%s: GMT SYNTAX ERROR -S option\n", GMT_program);
 		error++;
 	}
@@ -351,6 +351,7 @@ int main (int argc, char **argv)
 
 	if (error) exit (EXIT_FAILURE);
 
+	if (S.symbol > 0 && Ctrl->C.active) get_rgb = TRUE;
 	read_symbol = (S.symbol == GMT_SYMBOL_NOT_SET);
 
 	if (S.symbol == 0 && (Ctrl->G.active || Ctrl->L.active)) polygon = TRUE;
@@ -522,11 +523,11 @@ int main (int argc, char **argv)
 					i = strlen (GMT_io.current_record) - 1;
 					GMT_io.current_record[i--] = 0;	/* Chop off the \n */
 					while (GMT_io.current_record[i] && !strchr (" ,\t", (int)GMT_io.current_record[i])) i--;
-					GMT_decode_symbol_option (&GMT_io.current_record[i+1], &S, 1, FALSE);
+					GMT_parse_symbol_option (&GMT_io.current_record[i+1], &S, 1, FALSE);
 					n_required = n_cols_start + S.n_required;
 				}
 			/*	else {
-					GMT_decode_symbol_option (Ctrl->S.arg, &S, 1, FALSE);
+					GMT_parse_symbol_option (Ctrl->S.arg, &S, 1, FALSE);
 					n_required = n_cols_start + S.n_required;
 				} */
 
@@ -555,6 +556,21 @@ int main (int argc, char **argv)
 						data1[n].z_size *= (float)GMT_u2u[S.u][GMT_INCH];
 					}
 				}
+				else if (S.symbol == GMT_SYMBOL_ROTATERECT) {
+					data1[n].x_size = (float)in[three];	/* direction */
+					data1[n].y_size = (float)in[four];	/* width */
+					data1[n].z_size = (float)in[five];	/* height */
+					data1[n].flag = S.convert_angles;	/* Azim vs Dir. */
+					if (S.convert_angles == 1) {	/* Got axes in user units, change to inches */
+						data1[n].y_size *= (float)project_info.x_scale;
+						data1[n].z_size *= (float)project_info.x_scale;
+						data1[n].x_size = (float)(90.0 - data1[n].x_size);	/* Cartesian azimuth */
+					}
+					else if (S.convert_angles == 0){	/* Got axes in current plot units, change to inches */
+						data1[n].y_size *= (float)GMT_u2u[S.u][GMT_INCH];
+						data1[n].z_size *= (float)GMT_u2u[S.u][GMT_INCH];
+					}
+				}
 				else if (S.symbol == GMT_SYMBOL_PIE) {
 					data1[n].x_size = (float)S.size_x;
 					if (S.convert_angles == 1) {	/* Got azimuths instead */
@@ -730,6 +746,12 @@ int main (int argc, char **argv)
 						else
 							GMT_ellipse3D (data1[i].x, data1[i].y, data1[i].z, data1[i].x_size, data1[i].y_size, data1[i].z_size, data1[i].f.rgb, Ctrl->W.active);
 						break;
+					case GMT_SYMBOL_ROTATERECT:
+						if (data1[i].flag == 2)
+							GMT_plot_rectangle (data1[i].lon, data1[i].lat, data1[i].z, data1[i].y_size, data1[i].z_size, data1[i].x_size, Ctrl->G.fill, Ctrl->W.active);
+						else
+							GMT_rotrect3D (data1[i].x, data1[i].y, data1[i].z, data1[i].x_size, data1[i].y_size, data1[i].z_size, data1[i].f.rgb, Ctrl->W.active);
+						break;
 					case GMT_SYMBOL_TEXT:
 						font_size = 2.0 * data1[i].x_size * 72.0;	/* To get points */
 						if (Ctrl->W.active && Ctrl->G.active) {
